# Twittenizer: Convert stupid text in smart features.

The goal of this tool is to provide an advanced tokenizer for tweets.
It is build on top of NLTK tokenizer.

Inputs:

- Tweets in .json format
- Raw tweets in .txt format

Output:

- Tokens ready to fit in a neural network
